@@ -89,7 +89,10 @@ class USA:
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + usa_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + usa_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -149,7 +152,10 @@ class France:
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + france_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + france_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -218,8 +224,10 @@ class England:
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix,
-                 "url": URL + england_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + england_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -239,17 +247,25 @@ class GreatBritain:
     available = regions + england.available
     available.sort()
 
-    country = {"name": "great-britain" + suffix, "url": URL + europe_url + "great-britain" + suffix}
+    country = {
+        "name": "great-britain" + suffix,
+        "url": URL + europe_url + "great-britain" + suffix,
+    }
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + gb_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + gb_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
     for region in england.available:
-        _sources[region] = {"name": region.replace("_", "-") + suffix,
-                            "url": URL + england_url + region.replace("_", "-") + suffix}
+        _sources[region] = {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + england_url + region.replace("_", "-") + suffix,
+        }
 
     __dict__ = _sources
 
@@ -270,7 +286,10 @@ class Italy:
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + italy_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + italy_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -284,16 +303,18 @@ class Italy:
 
 
 class Russia:
-    regions = ["central_fed_district",
-               "crimean_fed_district",
-               "far_eastern_fed_district",
-               "kaliningrad",
-               "north_caucasus_fed_district",
-               "northwestern_fed_district",
-               "siberian_fed_district",
-               "south_fed_district",
-               "ural_fed_district",
-               "volga_fed_district"]
+    regions = [
+        "central_fed_district",
+        "crimean_fed_district",
+        "far_eastern_fed_district",
+        "kaliningrad",
+        "north_caucasus_fed_district",
+        "northwestern_fed_district",
+        "siberian_fed_district",
+        "south_fed_district",
+        "ural_fed_district",
+        "volga_fed_district",
+    ]
 
     available = regions
     available.sort()
@@ -302,7 +323,10 @@ class Russia:
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + russia_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + russia_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -316,23 +340,24 @@ class Russia:
 
 
 class Poland:
-    regions = ["dolnoslaskie",
-               "kujawsko_pomorskie",
-               "lodzkie",
-               "lubelskie",
-               "lubuskie",
-               "malopolskie",
-               "mazowieckie",
-               "opolskie",
-               "podkarpackie",
-               "podlaskie",
-               "pomorskie",
-               "slaskie",
-               "swietokrzyskie",
-               "warminsko_mazurskie",
-               "wielkopolskie",
-               "zachodniopomorskie"
-               ]
+    regions = [
+        "dolnoslaskie",
+        "kujawsko_pomorskie",
+        "lodzkie",
+        "lubelskie",
+        "lubuskie",
+        "malopolskie",
+        "mazowieckie",
+        "opolskie",
+        "podkarpackie",
+        "podlaskie",
+        "pomorskie",
+        "slaskie",
+        "swietokrzyskie",
+        "warminsko_mazurskie",
+        "wielkopolskie",
+        "zachodniopomorskie",
+    ]
 
     available = regions
     available.sort()
@@ -341,7 +366,10 @@ class Poland:
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + poland_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + poland_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -355,18 +383,22 @@ class Poland:
 
 
 class BadenWuerttemberg:
-    regions = ["freiburg_regbez",
-               "karlsruhe_regbez",
-               "stuttgart_regbez",
-               "tuebingen_regbez"]
+    regions = [
+        "freiburg_regbez",
+        "karlsruhe_regbez",
+        "stuttgart_regbez",
+        "tuebingen_regbez",
+    ]
 
     available = regions
     available.sort()
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix,
-                 "url": URL + baden_wuerttemberg_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + baden_wuerttemberg_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -380,19 +412,23 @@ class BadenWuerttemberg:
 
 
 class NordrheinWestfalen:
-    regions = ["arnsberg_regbez",
-               "detmold_regbez",
-               "duesseldorf_regbez",
-               "koeln_regbez",
-               "muenster_regbez"]
+    regions = [
+        "arnsberg_regbez",
+        "detmold_regbez",
+        "duesseldorf_regbez",
+        "koeln_regbez",
+        "muenster_regbez",
+    ]
 
     available = regions
     available.sort()
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix,
-                 "url": URL + nordrhein_wesfalen_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + nordrhein_wesfalen_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -406,21 +442,25 @@ class NordrheinWestfalen:
 
 
 class Bayern:
-    regions = ["mittelfranken",
-               "niederbayern",
-               "oberbayern",
-               "oberfranken",
-               "oberpfalz",
-               "schwaben",
-               "unterfranken"]
+    regions = [
+        "mittelfranken",
+        "niederbayern",
+        "oberbayern",
+        "oberfranken",
+        "oberpfalz",
+        "schwaben",
+        "unterfranken",
+    ]
 
     available = regions
     available.sort()
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix,
-                 "url": URL + bayern_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + bayern_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -434,51 +474,65 @@ class Bayern:
 
 
 class Germany:
-    regions = ["baden_wuerttemberg",
-               "bayern",
-               "berlin",
-               "brandenburg",
-               "bremen",
-               "hamburg",
-               "hessen",
-               "mecklenburg_vorpommern",
-               "niedersachsen",
-               "nordrhein_westfalen",
-               "rheinland_pfalz",
-               "saarland",
-               "sachsen_anhalt",
-               "sachsen",
-               "schleswig_holstein",
-               "thueringen"]
+    regions = [
+        "baden_wuerttemberg",
+        "bayern",
+        "berlin",
+        "brandenburg",
+        "bremen",
+        "hamburg",
+        "hessen",
+        "mecklenburg_vorpommern",
+        "niedersachsen",
+        "nordrhein_westfalen",
+        "rheinland_pfalz",
+        "saarland",
+        "sachsen_anhalt",
+        "sachsen",
+        "schleswig_holstein",
+        "thueringen",
+    ]
 
     baden_wuerttemberg = BadenWuerttemberg()
     bayern = Bayern()
     nordrhein_westfalen = NordrheinWestfalen()
 
-    available = regions + bayern.available + baden_wuerttemberg.available \
-                + nordrhein_westfalen.available
+    available = (
+        regions
+        + bayern.available
+        + baden_wuerttemberg.available
+        + nordrhein_westfalen.available
+    )
     available.sort()
 
     country = {"name": "germany" + suffix, "url": URL + europe_url + "germany" + suffix}
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix,
-                 "url": URL + germany_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + germany_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
     for region in nordrhein_westfalen.available:
-        _sources[region] = {"name": region.replace("_", "-") + suffix,
-                            "url": URL + nordrhein_wesfalen_url + region.replace("_", "-") + suffix}
+        _sources[region] = {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + nordrhein_wesfalen_url + region.replace("_", "-") + suffix,
+        }
 
     for region in baden_wuerttemberg.available:
-        _sources[region] = {"name": region.replace("_", "-") + suffix,
-                            "url": URL + baden_wuerttemberg_url + region.replace("_", "-") + suffix}
+        _sources[region] = {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + baden_wuerttemberg_url + region.replace("_", "-") + suffix,
+        }
 
     for region in bayern.available:
-        _sources[region] = {"name": region.replace("_", "-") + suffix,
-                            "url": URL + bayern_url + region.replace("_", "-") + suffix}
+        _sources[region] = {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + bayern_url + region.replace("_", "-") + suffix,
+        }
 
     __dict__ = _sources
 
@@ -490,27 +544,34 @@ class Germany:
 
 
 class Netherlands:
-    regions = ["drenthe",
-               "flevoland",
-               "friesland",
-               "gelderland",
-               "groningen",
-               "limburg",
-               "noord_brabant",
-               "noord_holland",
-               "overijssel",
-               "utrecht",
-               "zeeland",
-               "zuid_holland"]
+    regions = [
+        "drenthe",
+        "flevoland",
+        "friesland",
+        "gelderland",
+        "groningen",
+        "limburg",
+        "noord_brabant",
+        "noord_holland",
+        "overijssel",
+        "utrecht",
+        "zeeland",
+        "zuid_holland",
+    ]
     available = regions
     available.sort()
 
-    country = {"name": "netherlands" + suffix, "url": URL + europe_url + "netherlands" + suffix}
+    country = {
+        "name": "netherlands" + suffix,
+        "url": URL + europe_url + "netherlands" + suffix,
+    }
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix,
-                 "url": URL + netherlands_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + netherlands_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -524,27 +585,35 @@ class Netherlands:
 
 
 class Canada:
-    regions = ["alberta",
-               "british_columbia",
-               "manitoba",
-               "new_brunswick",
-               "newfoundland_and_labrador",
-               "northwest_territories",
-               "nova_scotia",
-               "nunavut",
-               "ontario",
-               "prince_edward_island",
-               "quebec",
-               "saskatchewan",
-               "yukon"]
+    regions = [
+        "alberta",
+        "british_columbia",
+        "manitoba",
+        "new_brunswick",
+        "newfoundland_and_labrador",
+        "northwest_territories",
+        "nova_scotia",
+        "nunavut",
+        "ontario",
+        "prince_edward_island",
+        "quebec",
+        "saskatchewan",
+        "yukon",
+    ]
     available = regions
     available.sort()
 
-    country = {"name": "canada" + suffix, "url": URL + north_america_url + "canada" + suffix}
+    country = {
+        "name": "canada" + suffix,
+        "url": URL + north_america_url + "canada" + suffix,
+    }
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + canada_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + canada_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -562,11 +631,17 @@ class Brazil:
     available = regions
     available.sort()
 
-    country = {"name": "brazil" + suffix, "url": URL + south_america_url + "brazil" + suffix}
+    country = {
+        "name": "brazil" + suffix,
+        "url": URL + south_america_url + "brazil" + suffix,
+    }
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + brazil_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + brazil_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -580,14 +655,16 @@ class Brazil:
 
 
 class Japan:
-    regions = ["chubu",
-               "chugoku",
-               "hokkaido",
-               "kansai",
-               "kanto",
-               "kyushu",
-               "shikoku",
-               "tohoku"]
+    regions = [
+        "chubu",
+        "chugoku",
+        "hokkaido",
+        "kansai",
+        "kanto",
+        "kyushu",
+        "shikoku",
+        "tohoku",
+    ]
 
     available = regions
     available.sort()
@@ -596,7 +673,10 @@ class Japan:
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + japan_url + region + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + japan_url + region + suffix,
+        }
         for region in regions
     }
 
@@ -610,33 +690,40 @@ class Japan:
 
 
 class AustraliaOceania:
-    regions = ["australia",
-               "cook_islands",
-               "fiji",
-               "kiribati",
-               "marshall_islands",
-               "micronesia",
-               "nauru",
-               "new_caledonia",
-               "new_zealand",
-               "niue",
-               "palau",
-               "papua_new_guinea",
-               "samoa",
-               "solomon_islands",
-               "tonga",
-               "tuvalu",
-               "vanuatu"]
+    regions = [
+        "australia",
+        "cook_islands",
+        "fiji",
+        "kiribati",
+        "marshall_islands",
+        "micronesia",
+        "nauru",
+        "new_caledonia",
+        "new_zealand",
+        "niue",
+        "palau",
+        "papua_new_guinea",
+        "samoa",
+        "solomon_islands",
+        "tonga",
+        "tuvalu",
+        "vanuatu",
+    ]
 
     available = regions
     available.sort()
 
-    continent = {"name": "australia-oceania" + suffix, "url": URL + "australia-oceania" + suffix}
+    continent = {
+        "name": "australia-oceania" + suffix,
+        "url": URL + "australia-oceania" + suffix,
+    }
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix,
-                 "url": URL + australia_oceania_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + australia_oceania_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -650,15 +737,17 @@ class AustraliaOceania:
 
 
 class NorthAmerica:
-    regions = ["canada",
-               "greenland",
-               "mexico",
-               "usa",
-               "us_midwest",
-               "us_northeast",
-               "us_pacific",
-               "us_south",
-               "us_west"]
+    regions = [
+        "canada",
+        "greenland",
+        "mexico",
+        "usa",
+        "us_midwest",
+        "us_northeast",
+        "us_pacific",
+        "us_south",
+        "us_west",
+    ]
 
     usa = USA()
     canada = Canada()
@@ -666,17 +755,25 @@ class NorthAmerica:
     available = regions
     available.sort()
 
-    continent = {"name": "north-america" + suffix, "url": URL + "north-america" + suffix}
+    continent = {
+        "name": "north-america" + suffix,
+        "url": URL + "north-america" + suffix,
+    }
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix,
-                 "url": URL + north_america_url + region.replace("_", "-") + suffix}
-        for region in regions if region != "usa"
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + north_america_url + region.replace("_", "-") + suffix,
+        }
+        for region in regions
+        if region != "usa"
     }
     # USA is "us" in GeoFabrik
-    _sources["usa"] = {"name": "us" + suffix,
-                       "url": URL + north_america_url + "us" + suffix}
+    _sources["usa"] = {
+        "name": "us" + suffix,
+        "url": URL + north_america_url + "us" + suffix,
+    }
 
     __dict__ = _sources
 
@@ -688,17 +785,19 @@ class NorthAmerica:
 
 
 class SouthAmerica:
-    regions = ["argentina",
-               "bolivia",
-               "brazil",
-               "chile",
-               "colombia",
-               "ecuador",
-               "paraguay",
-               "peru",
-               "suriname",
-               "uruguay",
-               "venezuela"]
+    regions = [
+        "argentina",
+        "bolivia",
+        "brazil",
+        "chile",
+        "colombia",
+        "ecuador",
+        "paraguay",
+        "peru",
+        "suriname",
+        "uruguay",
+        "venezuela",
+    ]
 
     brazil = Brazil()
 
@@ -706,11 +805,17 @@ class SouthAmerica:
     available.sort()
     available.sort()
 
-    continent = {"name": "south-america" + suffix, "url": URL + "south-america" + suffix}
+    continent = {
+        "name": "south-america" + suffix,
+        "url": URL + "south-america" + suffix,
+    }
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + south_america_url + region + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + south_america_url + region + suffix,
+        }
         for region in regions
     }
 
@@ -724,23 +829,30 @@ class SouthAmerica:
 
 
 class CentralAmerica:
-    regions = ["bahamas",
-               "belize",
-               "cuba",
-               "guatemala",
-               "haiti_and_domrep",
-               "jamaica",
-               "nicaragua"]
+    regions = [
+        "bahamas",
+        "belize",
+        "cuba",
+        "guatemala",
+        "haiti_and_domrep",
+        "jamaica",
+        "nicaragua",
+    ]
 
     available = regions
     available.sort()
 
-    continent = {"name": "central-america" + suffix, "url": URL + "central-america" + suffix}
+    continent = {
+        "name": "central-america" + suffix,
+        "url": URL + "central-america" + suffix,
+    }
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix,
-                 "url": URL + central_america_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + central_america_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -822,12 +934,15 @@ class Europe:
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + europe_url + region.replace("_", "-") + suffix}
-        for region in regions if region != "russia"
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + europe_url + region.replace("_", "-") + suffix,
+        }
+        for region in regions
+        if region != "russia"
     }
     # Russia is separately from Europe
-    _sources["russia"] = {"name": "russia" + suffix,
-                          "url": URL + "russia" + suffix}
+    _sources["russia"] = {"name": "russia" + suffix, "url": URL + "russia" + suffix}
 
     __dict__ = _sources
 
@@ -839,62 +954,64 @@ class Europe:
 
 
 class Africa:
-    regions = ["algeria",
-               "angola",
-               "benin",
-               "botswana",
-               "burkina_faso",
-               "burundi",
-               "cameroon",
-               "canary_islands",
-               "cape_verde",
-               "central_african_republic",
-               "chad",
-               "comores",
-               "congo_brazzaville",
-               "congo_democratic_republic",
-               "djibouti",
-               "egypt",
-               "equatorial_guinea",
-               "eritrea",
-               "ethiopia",
-               "gabon",
-               "ghana",
-               "guinea_bissau",
-               "guinea",
-               "ivory_coast",
-               "kenya",
-               "lesotho",
-               "liberia",
-               "libya",
-               "madagascar",
-               "malawi",
-               "mali",
-               "mauritania",
-               "mauritius",
-               "morocco",
-               "mozambique",
-               "namibia",
-               "niger",
-               "nigeria",
-               "rwanda",
-               "saint_helena_ascension_and_tristan_da_cunha",
-               "sao_tome_and_principe",
-               "senegal_and_gambia",
-               "seychelles",
-               "sierra_leone",
-               "somalia",
-               "south_africa_and_lesotho",
-               "south_africa",
-               "south_sudan",
-               "sudan",
-               "swaziland",
-               "tanzania",
-               "togo",
-               "tunisia",
-               "uganda",
-               "zambia",
-               "zimbabwe"]
+    regions = [
+        "algeria",
+        "angola",
+        "benin",
+        "botswana",
+        "burkina_faso",
+        "burundi",
+        "cameroon",
+        "canary_islands",
+        "cape_verde",
+        "central_african_republic",
+        "chad",
+        "comores",
+        "congo_brazzaville",
+        "congo_democratic_republic",
+        "djibouti",
+        "egypt",
+        "equatorial_guinea",
+        "eritrea",
+        "ethiopia",
+        "gabon",
+        "ghana",
+        "guinea_bissau",
+        "guinea",
+        "ivory_coast",
+        "kenya",
+        "lesotho",
+        "liberia",
+        "libya",
+        "madagascar",
+        "malawi",
+        "mali",
+        "mauritania",
+        "mauritius",
+        "morocco",
+        "mozambique",
+        "namibia",
+        "niger",
+        "nigeria",
+        "rwanda",
+        "saint_helena_ascension_and_tristan_da_cunha",
+        "sao_tome_and_principe",
+        "senegal_and_gambia",
+        "seychelles",
+        "sierra_leone",
+        "somalia",
+        "south_africa_and_lesotho",
+        "south_africa",
+        "south_sudan",
+        "sudan",
+        "swaziland",
+        "tanzania",
+        "togo",
+        "tunisia",
+        "uganda",
+        "zambia",
+        "zimbabwe",
+    ]
 
     available = regions
     available.sort()
@@ -903,7 +1020,10 @@ class Africa:
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + africa_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + africa_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -917,43 +1037,45 @@ class Africa:
 
 
 class Asia:
-    regions = ["afghanistan",
-               "armenia",
-               "azerbaijan",
-               "bangladesh",
-               "bhutan",
-               "cambodia",
-               "china",
-               "gcc_states",
-               "india",
-               "indonesia",
-               "iran",
-               "iraq",
-               "israel_and_palestine",
-               "japan",
-               "jordan",
-               "kazakhstan",
-               "kyrgyzstan",
-               "laos",
-               "lebanon",
-               "malaysia_singapore_brunei",
-               "maldives",
-               "mongolia",
-               "myanmar",
-               "nepal",
-               "north_korea",
-               "pakistan",
-               "philippines",
-               "south_korea",
-               "sri_lanka",
-               "syria",
-               "taiwan",
-               "tajikistan",
-               "thailand",
-               "turkmenistan",
-               "uzbekistan",
-               "vietnam",
-               "yemen"]
+    regions = [
+        "afghanistan",
+        "armenia",
+        "azerbaijan",
+        "bangladesh",
+        "bhutan",
+        "cambodia",
+        "china",
+        "gcc_states",
+        "india",
+        "indonesia",
+        "iran",
+        "iraq",
+        "israel_and_palestine",
+        "japan",
+        "jordan",
+        "kazakhstan",
+        "kyrgyzstan",
+        "laos",
+        "lebanon",
+        "malaysia_singapore_brunei",
+        "maldives",
+        "mongolia",
+        "myanmar",
+        "nepal",
+        "north_korea",
+        "pakistan",
+        "philippines",
+        "south_korea",
+        "sri_lanka",
+        "syria",
+        "taiwan",
+        "tajikistan",
+        "thailand",
+        "turkmenistan",
+        "uzbekistan",
+        "vietnam",
+        "yemen",
+    ]
 
     japan = Japan()
 
@@ -964,7 +1086,10 @@ class Asia:
 
     # Create data sources
     _sources = {
-        region: {"name": region.replace("_", "-") + suffix, "url": URL + asia_url + region.replace("_", "-") + suffix}
+        region: {
+            "name": region.replace("_", "-") + suffix,
+            "url": URL + asia_url + region.replace("_", "-") + suffix,
+        }
         for region in regions
     }
 
@@ -1001,7 +1126,19 @@ class Antarctica:
 
 class SubRegions:
     def __init__(self):
-        self.regions = ["brazil", "canada", "france", "germany", "great_britain", "italy", "japan", "netherlands", "poland", "russia", "usa"]
+        self.regions = [
+            "brazil",
+            "canada",
+            "france",
+            "germany",
+            "great_britain",
+            "italy",
+            "japan",
+            "netherlands",
+            "poland",
+            "russia",
+            "usa",
+        ]
         available = self.regions
         available.sort()
 
