@@ -1,14 +1,28 @@
+import numpy as np
 from pyrosm.config import Conf
 from pyrosm.pbfreader import parse_osm_data
 from pyrosm._arrays import concatenate_dicts_of_arrays
 from pyrosm.geometry import create_node_coordinates_lookup
 from pyrosm.frames import create_nodes_gdf
-from pyrosm.utils import validate_custom_filter, validate_osm_keys, \
-    validate_tags_as_columns, validate_booleans, validate_boundary_type, \
-    validate_bounding_box, validate_input_file, get_bounding_box
+from pyrosm.utils import (
+    validate_custom_filter,
+    validate_osm_keys,
+    validate_tags_as_columns,
+    validate_booleans,
+    validate_boundary_type,
+    validate_bounding_box,
+    validate_input_file,
+    validate_graph_type,
+    get_bounding_box,
+)
 from pyrosm.utils.download import get_file_size
-from shapely.geometry import Polygon, MultiPolygon, \
-    LineString, LinearRing, MultiLineString
+from shapely.geometry import (
+    Polygon,
+    MultiPolygon,
+    LineString,
+    LinearRing,
+    MultiLineString,
+)
 from pyrosm.boundary import get_boundary_data
 from pyrosm.buildings import get_building_data
 from pyrosm.landuse import get_landuse_data
@@ -16,28 +30,36 @@ from pyrosm.natural import get_natural_data
 from pyrosm.networks import get_network_data
 from pyrosm.pois import get_poi_data
 from pyrosm.user_defined import get_user_defined_data
+from pyrosm.graphs import to_networkx, to_igraph, to_pandana
 
 
 class OSM:
+    """
+    OpenStreetMap PBF reader object.
+
+    Parameters
+    ----------
+
+    filepath : str
+        Filepath to input OSM dataset ( *.osm.pbf )
+
+    bounding_box : list | shapely geometry
+        Filtering OSM data spatially is allowed by passing a
+        bounding box either as a list `[minx, miny, maxx, maxy]` or
+        as a Shapely Polygon/MultiPolygon or closed LineString/LinearRing.
+    """
+
     from pyrosm.utils._compat import PYGEOS_SHAPELY_COMPAT
-    allowed_bbox_types = [Polygon, MultiPolygon, MultiLineString,
-                          LineString, LinearRing]
 
-    def __init__(self, filepath,
-                 bounding_box=None):
-        """
-        Parameters
-        ----------
+    allowed_bbox_types = [
+        Polygon,
+        MultiPolygon,
+        MultiLineString,
+        LineString,
+        LinearRing,
+    ]
 
-        filepath : str
-            Filepath to input OSM dataset ( *.osm.pbf )
-
-        bounding_box : list | shapely geometry
-            Filtering OSM data spatially is allowed by passing a
-            bounding box either as a list `[minx, miny, maxx, maxy]` or
-            as a Shapely Polygon/MultiPolygon or closed LineString/LinearRing.
-
-        """
+    def __init__(self, filepath, bounding_box=None):
 
         # Check input file
         self.filepath = validate_input_file(filepath)
@@ -50,11 +72,15 @@ class OSM:
             self.bounding_box = validate_bounding_box(bounding_box)
         elif isinstance(bounding_box, list):
             if not len(bounding_box) == 4:
-                raise ValueError("When passing bounding box as a list it should contain 4 coordinates: "
-                                 "[minx, miny, maxx, maxy].")
+                raise ValueError(
+                    "When passing bounding box as a list it should contain 4 coordinates: "
+                    "[minx, miny, maxx, maxy]."
+                )
             self.bounding_box = bounding_box
         else:
-            raise ValueError("bounding_box should be a list, Shapely Polygon or a Shapely LinearRing.")
+            raise ValueError(
+                "bounding_box should be a list, Shapely Polygon or a Shapely LinearRing."
+            )
 
         self.conf = Conf
         self.keep_node_info = False
@@ -82,9 +108,9 @@ class OSM:
         else:
             bounding_box = self.bounding_box
 
-        nodes, ways, relations, way_tags = parse_osm_data(self.filepath,
-                                             bounding_box,
-                                             exclude_relations=False)
+        nodes, ways, relations, way_tags = parse_osm_data(
+            self.filepath, bounding_box, exclude_relations=False
+        )
 
         self._nodes = nodes
         self._way_records = ways
@@ -95,9 +121,7 @@ class OSM:
         self._node_coordinates = create_node_coordinates_lookup(self._nodes)
 
     def _get_network_filter(self, net_type):
-        possible_filters = [a for a in self.conf.network_filters.__dir__()
-                            if "__" not in a]
-        possible_filters += ["all", "driving+service"]
+        possible_filters = self.conf._possible_network_filters
         possible_values = ", ".join(possible_filters)
         msg = "'network_type' should be one of the following: " + possible_values
         if not isinstance(net_type, str):
@@ -120,7 +144,12 @@ class OSM:
         elif net_type == "all":
             return None
 
-    def get_network(self, network_type="walking", extra_attributes=None):
+    def get_network(
+        self,
+        network_type="walking",
+        extra_attributes=None,
+        nodes=False,
+    ):
         """
         Parses street networks from OSM
         for walking, driving, and cycling.
@@ -140,12 +169,26 @@ class OSM:
         extra_attributes : list (optional)
             Additional OSM tag keys that will be converted into columns in the resulting GeoDataFrame.
 
+        nodes : bool (default: False)
+            If True, 1) the nodes associated with the network will be returned in addition to edges,
+            and 2) every segment of a road constituting a way is parsed as a separate row
+            (to enable full connectivity in the graph).
+
+        Returns
+        -------
+
+        gdf_edges or (gdf_nodes, gdf_edges)
+
+        Return type
+        -----------
+
+        geopandas.GeoDataFrame or tuple
+
         See Also
         --------
 
         Take a look at the OSM documentation for further details about the data:
         `https://wiki.openstreetmap.org/wiki/Key:highway <https://wiki.openstreetmap.org/wiki/Key:highway>`__
-
         """
         # Get filter
         network_filter = self._get_network_filter(network_type)
@@ -159,20 +202,29 @@ class OSM:
             self._read_pbf()
 
         # Filter network data with given filter
-        gdf = get_network_data(self._node_coordinates,
-                               self._way_records,
-                               tags_as_columns,
-                               network_filter,
-                               self.bounding_box
-                               )
+        edges, node_gdf = get_network_data(
+            self._node_coordinates,
+            self._way_records,
+            tags_as_columns,
+            network_filter,
+            self.bounding_box,
+            slice_to_segments=nodes,
+        )
+
+        if edges is not None:
+            # Add metadata
+            edges._metadata.append(network_type)
 
         # Do not keep node information unless specifically asked for
         # (they are in a list, and can cause issues when saving the files)
-        if not self.keep_node_info and gdf is not None:
-            if "nodes" in gdf.columns:
-                gdf = gdf.drop("nodes", axis=1)
+        if not self.keep_node_info and edges is not None:
+            if "nodes" in edges.columns:
+                edges = edges.drop("nodes", axis=1)
 
-        return gdf
+        # In case both edges and nodes are requested
+        if nodes:
+            return (node_gdf, edges)
+        return edges
 
     def get_buildings(self, custom_filter=None, extra_attributes=None):
         """
@@ -210,13 +262,14 @@ class OSM:
         if self._nodes is None or self._way_records is None:
             self._read_pbf()
 
-        gdf = get_building_data(self._node_coordinates,
-                                self._way_records,
-                                self._relations,
-                                tags_as_columns,
-                                custom_filter,
-                                self.bounding_box
-                                )
+        gdf = get_building_data(
+            self._node_coordinates,
+            self._way_records,
+            self._relations,
+            tags_as_columns,
+            custom_filter,
+            self.bounding_box,
+        )
 
         # Do not keep node information unless specifically asked for
         # (they are in a list, and can cause issues when saving the files)
@@ -267,14 +320,15 @@ class OSM:
         if isinstance(self._nodes, list):
             self._nodes = concatenate_dicts_of_arrays(self._nodes)
 
-        gdf = get_landuse_data(self._nodes,
-                               self._node_coordinates,
-                               self._way_records,
-                               self._relations,
-                               tags_as_columns,
-                               custom_filter,
-                               self.bounding_box
-                               )
+        gdf = get_landuse_data(
+            self._nodes,
+            self._node_coordinates,
+            self._way_records,
+            self._relations,
+            tags_as_columns,
+            custom_filter,
+            self.bounding_box,
+        )
 
         # Do not keep node information unless specifically asked for
         # (they are in a list, and can cause issues when saving the files)
@@ -325,13 +379,15 @@ class OSM:
         if isinstance(self._nodes, list):
             self._nodes = concatenate_dicts_of_arrays(self._nodes)
 
-        gdf = get_natural_data(self._nodes,
-                               self._node_coordinates,
-                               self._way_records,
-                               self._relations,
-                               tags_as_columns,
-                               custom_filter,
-                               self.bounding_box)
+        gdf = get_natural_data(
+            self._nodes,
+            self._node_coordinates,
+            self._way_records,
+            self._relations,
+            tags_as_columns,
+            custom_filter,
+            self.bounding_box,
+        )
 
         # Do not keep node information unless specifically asked for
         # (they are in a list, and can cause issues when saving the files)
@@ -340,7 +396,13 @@ class OSM:
                 gdf = gdf.drop("nodes", axis=1)
         return gdf
 
-    def get_boundaries(self, boundary_type="administrative", name=None, custom_filter=None, extra_attributes=None):
+    def get_boundaries(
+        self,
+        boundary_type="administrative",
+        name=None,
+        custom_filter=None,
+        extra_attributes=None,
+    ):
         """
         Parses boundaries from OSM.
 
@@ -400,17 +462,20 @@ class OSM:
 
         if name is not None:
             if not isinstance(name, str):
-                raise ValueError(f"'name' should be text."
-                                 f"Got '{name}' of type {type(name)}.")
+                raise ValueError(
+                    f"'name' should be text." f"Got '{name}' of type {type(name)}."
+                )
 
-        gdf = get_boundary_data(self._node_coordinates,
-                                self._way_records,
-                                self._relations,
-                                tags_as_columns,
-                                custom_filter,
-                                boundary_type,
-                                name,
-                                self.bounding_box)
+        gdf = get_boundary_data(
+            self._node_coordinates,
+            self._way_records,
+            self._relations,
+            tags_as_columns,
+            custom_filter,
+            boundary_type,
+            name,
+            self.bounding_box,
+        )
 
         # Do not keep node information unless specifically asked for
         # (they are in a list, and can cause issues when saving the files)
@@ -477,16 +542,15 @@ class OSM:
         """
         # If custom_filter has not been defined, initialize with default
         if custom_filter is None:
-            custom_filter = {"amenity": True,
-                             "shop": True,
-                             "tourism": True
-                             }
+            custom_filter = {"amenity": True, "shop": True, "tourism": True}
 
         else:
             # Check that the custom filter is in correct format
             if not isinstance(custom_filter, dict):
-                raise ValueError(f"'custom_filter' should be a Python dictionary. "
-                                 f"Got {custom_filter} with type {type(custom_filter)}.")
+                raise ValueError(
+                    f"'custom_filter' should be a Python dictionary. "
+                    f"Got {custom_filter} with type {type(custom_filter)}."
+                )
 
         if self._nodes is None or self._way_records is None:
             self._read_pbf()
@@ -494,7 +558,12 @@ class OSM:
         # Default tags to keep as columns
         tags_as_columns = []
         for k in custom_filter.keys():
-            tags_as_columns += getattr(self.conf.tags, k)
+            try:
+                tags_as_columns += getattr(self.conf.tags, k)
+            except AttributeError:
+                tags_as_columns += self.conf.tags._basic_tags
+            except Exception as e:
+                raise e
 
         if extra_attributes is not None:
             validate_tags_as_columns(extra_attributes)
@@ -504,13 +573,15 @@ class OSM:
         if isinstance(self._nodes, list):
             self._nodes = concatenate_dicts_of_arrays(self._nodes)
 
-        gdf = get_poi_data(self._nodes,
-                           self._node_coordinates,
-                           self._way_records,
-                           self._relations,
-                           tags_as_columns,
-                           custom_filter,
-                           self.bounding_box)
+        gdf = get_poi_data(
+            self._nodes,
+            self._node_coordinates,
+            self._way_records,
+            self._relations,
+            tags_as_columns,
+            custom_filter,
+            self.bounding_box,
+        )
 
         # Do not keep node information unless specifically asked for
         # (they are in a list, and can cause issues when saving the files)
@@ -519,16 +590,19 @@ class OSM:
                 gdf = gdf.drop("nodes", axis=1)
         return gdf
 
-    def get_data_by_custom_criteria(self,
-                                    custom_filter,
-                                    osm_keys_to_keep=None,
-                                    filter_type="keep",
-                                    tags_as_columns=None,
-                                    keep_nodes=True,
-                                    keep_ways=True,
-                                    keep_relations=True,
-                                    extra_attributes=None):
+    def get_data_by_custom_criteria(
+        self,
+        custom_filter,
+        osm_keys_to_keep=None,
+        filter_type="keep",
+        tags_as_columns=None,
+        keep_nodes=True,
+        keep_ways=True,
+        keep_relations=True,
+        extra_attributes=None,
+    ):
         """
+        `
         Parse OSM data based on custom criteria.
 
         Parameters
@@ -544,10 +618,6 @@ class OSM:
             "keep" | "exclude"
             Whether the filters should be used to keep or exclude the data from OSM.
 
-            Note: "exclude" works only with ways and relations. With nodes, only "keep" is supported,
-            because with "exclude" almost all nodes would always be part of the end result as
-            most nodes do not have tag information.
-
         tags_as_columns : list
             Which tags should be kept as columns in the resulting GeoDataFrame.
 
@@ -566,10 +636,12 @@ class OSM:
         """
 
         # Check that the custom filter is in correct format
-        validate_custom_filter(custom_filter)
+        custom_filter = validate_custom_filter(custom_filter)
 
         if not isinstance(filter_type, str):
-            raise ValueError("'filter_type' -parameter should be either 'keep' or 'exclude'. ")
+            raise ValueError(
+                "'filter_type' -parameter should be either 'keep' or 'exclude'. "
+            )
 
         # Validate osm keys
         validate_osm_keys(osm_keys_to_keep)
@@ -579,7 +651,9 @@ class OSM:
         # Validate filter
         filter_type = filter_type.lower()
         if filter_type not in ["keep", "exclude"]:
-            raise ValueError("'filter_type' -parameter should be either 'keep' or 'exclude'. ")
+            raise ValueError(
+                "'filter_type' -parameter should be either 'keep' or 'exclude'. "
+            )
 
         # Tags to keep as columns
         if tags_as_columns is None:
@@ -612,19 +686,20 @@ class OSM:
         if isinstance(self._nodes, list):
             self._nodes = concatenate_dicts_of_arrays(self._nodes)
 
-        gdf = get_user_defined_data(self._nodes,
-                                    self._node_coordinates,
-                                    self._way_records,
-                                    self._relations,
-                                    tags_as_columns,
-                                    custom_filter,
-                                    osm_keys_to_keep,
-                                    filter_type,
-                                    keep_nodes,
-                                    keep_ways,
-                                    keep_relations,
-                                    self.bounding_box
-                                    )
+        gdf = get_user_defined_data(
+            self._nodes,
+            self._node_coordinates,
+            self._way_records,
+            self._relations,
+            tags_as_columns,
+            custom_filter,
+            osm_keys_to_keep,
+            filter_type,
+            keep_nodes,
+            keep_ways,
+            keep_relations,
+            self.bounding_box,
+        )
 
         # Do not keep node information unless specifically asked for
         # (they are in a list, and can cause issues when saving the files)
@@ -633,6 +708,130 @@ class OSM:
                 gdf = gdf.drop("nodes", axis=1)
         return gdf
 
+    def to_graph(
+        self,
+        nodes,
+        edges,
+        graph_type="igraph",
+        direction="oneway",
+        from_id_col="u",
+        to_id_col="v",
+        edge_id_col="id",
+        node_id_col="id",
+        force_bidirectional=False,
+        network_type=None,
+        retain_all=False,
+        osmnx_compatible=True,
+        pandana_weights=["length"],
+    ):
+        """
+        `
+        Export OSM network to routable graph. Supported output graph types are:
+          - "igraph" (default),
+          - "networkx",
+          - "pandana"
+
+        For walking and cycling, the output graph will be bidirectional by default
+        (i.e. travel along the street is allowed to both directions). For driving,
+        one-way streets are taken into account by default and the travel is restricted
+        based on the rules in OSM data (based on "oneway" attribute).
+
+        Parameters
+        ----------
+
+        nodes : GeoDataFrame
+            GeoDataFrame containing nodes of the road network.
+            Note: Use `osm.get_network(nodes=True)` to retrieve both the nodes and edges.
+
+        edges : GeoDataFrame
+            GeoDataFrame containing the edges of the road network.
+
+        graph_type : str
+            Type of the output graph. Available graphs are:
+              - "igraph" --> returns an igraph.Graph -object.
+              - "networkx" --> returns a networkx.MultiDiGraph -object.
+              - "pandana" --> returns an pandana.Network -object.
+
+        direction : str
+            Name for the column containing information about the allowed driving directions
+
+        from_id_col : str
+            Name for the column having the from-node-ids of edges.
+
+        to_id_col : str
+            Name for the column having the to-node-ids of edges.
+
+        edge_id_col : str
+            Name for the column having the unique id for edges.
+
+        node_id_col : str
+            Name for the column having the unique id for nodes.
+
+        force_bidirectional : bool
+            If True, all edges will be created as bidirectional (allow travel to both directions).
+
+        network_type : str (optional)
+            Network type for the given data. Determines how the graph will be constructed.
+            The network type is typically extracted automatically from the metadata of
+            the edges/nodes GeoDataFrames. This parameter can be used if this metadata is not
+            available for a reason or another. By default, bidirectional graph is created for walking, cycling and all,
+            and directed graph for driving (i.e. oneway streets are taken into account).
+            Possible values are: 'walking', 'cycling', 'driving', 'driving+service', 'all'.
+
+        retain_all : bool
+            if True, return the entire graph even if it is not connected.
+            otherwise, retain only the connected edges.
+
+        osmnx_compatible : bool (default True)
+            if True, modifies the edge and node-attribute naming to be compatible with OSMnx
+            (allows utilizing all OSMnx functionalities).
+            NOTE: Only applicable with "networkx" graph type.
+
+        pandana_weights : list
+            Columns that are used as weights when exporting to Pandana graph. By default uses "length" column.
+        """
+        graph_type = validate_graph_type(graph_type)
+
+        if graph_type == "igraph":
+            return to_igraph(
+                nodes,
+                edges,
+                direction,
+                from_id_col,
+                to_id_col,
+                node_id_col,
+                force_bidirectional,
+                network_type,
+                retain_all,
+            )
+        elif graph_type == "networkx":
+            return to_networkx(
+                nodes,
+                edges,
+                direction,
+                from_id_col,
+                to_id_col,
+                edge_id_col,
+                node_id_col,
+                force_bidirectional,
+                network_type,
+                retain_all,
+                osmnx_compatible,
+            )
+        elif graph_type == "pandana":
+            return to_pandana(
+                nodes,
+                edges,
+                direction,
+                from_id_col,
+                to_id_col,
+                node_id_col,
+                force_bidirectional,
+                network_type,
+                retain_all,
+                pandana_weights,
+            )
+
     def __getattribute__(self, name):
         # If node-gdf is requested convert to gdf before returning
         if name == "_nodes_gdf":
