@@ -22,18 +22,20 @@ def helsinki_region_pbf():
 
 @pytest.fixture
 def default_filter():
-    return {"amenity": True,
-            "craft": True,
-            "historic": True,
-            "leisure": True,
-            "shop": True,
-            "tourism": True
-            }
+    return {
+        "amenity": True,
+        "craft": True,
+        "historic": True,
+        "leisure": True,
+        "shop": True,
+        "tourism": True,
+    }
 
 
 @pytest.fixture
 def test_output_dir():
     import os, tempfile
+
     return os.path.join(tempfile.gettempdir(), "pyrosm_test_results")
 
 
@@ -41,6 +43,7 @@ def test_parsing_osm_with_custom_filter_by_excluding_tags(test_pbf):
     from pyrosm import OSM
     from geopandas import GeoDataFrame
     import pyproj
+
     osm = OSM(filepath=test_pbf)
 
     # Keep only building as column
@@ -49,17 +52,26 @@ def test_parsing_osm_with_custom_filter_by_excluding_tags(test_pbf):
     custom_filter = {"building": ["residential"]}
     filter_type = "exclude"
     osm_type = "building"
-    gdf = osm.get_data_by_custom_criteria(custom_filter=custom_filter,
-                                         filter_type=filter_type,
-                                         osm_keys_to_keep=osm_type,
-                                         tags_as_columns=tags_as_columns
-                                         )
+    gdf = osm.get_data_by_custom_criteria(
+        custom_filter=custom_filter,
+        filter_type=filter_type,
+        osm_keys_to_keep=osm_type,
+        tags_as_columns=tags_as_columns,
+    )
 
     assert isinstance(gdf, GeoDataFrame)
 
     # Only following columns should exist after specifying tags_as_columns
-    allowed_columns = ["geometry", "tags", "building", "id", "osm_type",
-                       "version", "timestamp", "changeset"]
+    allowed_columns = [
+        "geometry",
+        "tags",
+        "building",
+        "id",
+        "osm_type",
+        "version",
+        "timestamp",
+        "changeset",
+    ]
     for col in gdf.columns:
         assert col in allowed_columns
 
@@ -67,7 +79,7 @@ def test_parsing_osm_with_custom_filter_by_excluding_tags(test_pbf):
     assert "residential" not in gdf["building"].tolist()
 
     # Required keys
-    required = ['id', 'geometry']
+    required = ["id", "geometry"]
     for col in required:
         assert col in gdf.columns
 
@@ -80,6 +92,7 @@ def test_parsing_osm_with_custom_filter_by_including_tags(test_pbf):
     from pyrosm import OSM
     from geopandas import GeoDataFrame
     import pyproj
+
     osm = OSM(filepath=test_pbf)
 
     # Keep only building as column
@@ -88,17 +101,26 @@ def test_parsing_osm_with_custom_filter_by_including_tags(test_pbf):
     custom_filter = {"building": ["retail"]}
     filter_type = "keep"
     osm_type = "building"
-    gdf = osm.get_data_by_custom_criteria(custom_filter=custom_filter,
-                                         filter_type=filter_type,
-                                         osm_keys_to_keep=osm_type,
-                                         tags_as_columns=tags_as_columns
-                                         )
+    gdf = osm.get_data_by_custom_criteria(
+        custom_filter=custom_filter,
+        filter_type=filter_type,
+        osm_keys_to_keep=osm_type,
+        tags_as_columns=tags_as_columns,
+    )
 
     assert isinstance(gdf, GeoDataFrame)
 
     # Only following columns should exist after specifying tags_as_columns
-    allowed_columns = ["geometry", "tags", "building", "id", "osm_type",
-                       "version", "timestamp", "changeset"]
+    allowed_columns = [
+        "geometry",
+        "tags",
+        "building",
+        "id",
+        "osm_type",
+        "version",
+        "timestamp",
+        "changeset",
+    ]
     for col in gdf.columns:
         assert col in allowed_columns
 
@@ -107,7 +129,7 @@ def test_parsing_osm_with_custom_filter_by_including_tags(test_pbf):
     assert gdf["building"].unique()[0] == "retail"
 
     # Required keys
-    required = ['id', 'geometry']
+    required = ["id", "geometry"]
     for col in required:
         assert col in gdf.columns
 
@@ -118,6 +140,7 @@ def test_parsing_osm_with_custom_filter_by_including_tags(test_pbf):
 
 def test_using_incorrect_filter(test_pbf):
     from pyrosm import OSM
+
     osm = OSM(filepath=test_pbf)
 
     # Test that passing incorrect data works as should
@@ -163,6 +186,7 @@ def test_using_incorrect_filter(test_pbf):
 
 def test_using_incorrect_tags(test_pbf):
     from pyrosm import OSM
+
     osm = OSM(filepath=test_pbf)
 
     # Incorrect tags
@@ -171,9 +195,9 @@ def test_using_incorrect_tags(test_pbf):
     custom_filter = {"building": ["retail"]}
     # Test that passing incorrect data works as should
     try:
-        gdf = osm.get_data_by_custom_criteria(custom_filter=custom_filter,
-                                             tags_as_columns=tags_as_columns
-                                             )
+        gdf = osm.get_data_by_custom_criteria(
+            custom_filter=custom_filter, tags_as_columns=tags_as_columns
+        )
     except ValueError as e:
         if "All tags listed in 'tags_as_columns' should be strings" in str(e):
             pass
@@ -183,15 +207,16 @@ def test_using_incorrect_tags(test_pbf):
 
 def test_using_incorrect_filter_type(test_pbf):
     from pyrosm import OSM
+
     osm = OSM(filepath=test_pbf)
 
     custom_filter = {"building": ["retail"]}
     filter_type = "incorrect_test"
     # Test that passing incorrect data works as should
     try:
-        gdf = osm.get_data_by_custom_criteria(custom_filter=custom_filter,
-                                             filter_type=filter_type
-                                             )
+        gdf = osm.get_data_by_custom_criteria(
+            custom_filter=custom_filter, filter_type=filter_type
+        )
     except ValueError as e:
         if "should be either 'keep' or 'exclude'" in str(e):
             pass
@@ -201,15 +226,16 @@ def test_using_incorrect_filter_type(test_pbf):
 
 def test_using_incorrect_booleans(test_pbf):
     from pyrosm import OSM
+
     osm = OSM(filepath=test_pbf)
 
     custom_filter = {"building": ["retail"]}
     incorrect_bool = "foo"
     # Test that passing incorrect data works as should
     try:
-        gdf = osm.get_data_by_custom_criteria(custom_filter=custom_filter,
-                                             keep_nodes=incorrect_bool
-                                             )
+        gdf = osm.get_data_by_custom_criteria(
+            custom_filter=custom_filter, keep_nodes=incorrect_bool
+        )
     except ValueError as e:
         if "'keep_nodes' should be boolean type: True or False" in str(e):
             pass
@@ -217,9 +243,9 @@ def test_using_incorrect_booleans(test_pbf):
             raise e
 
     try:
-        gdf = osm.get_data_by_custom_criteria(custom_filter=custom_filter,
-                                             keep_ways=incorrect_bool
-                                             )
+        gdf = osm.get_data_by_custom_criteria(
+            custom_filter=custom_filter, keep_ways=incorrect_bool
+        )
     except ValueError as e:
         if "'keep_ways' should be boolean type: True or False" in str(e):
             pass
@@ -227,22 +253,22 @@ def test_using_incorrect_booleans(test_pbf):
             raise e
 
     try:
-        gdf = osm.get_data_by_custom_criteria(custom_filter=custom_filter,
-                                             keep_relations=incorrect_bool
-                                             )
+        gdf = osm.get_data_by_custom_criteria(
+            custom_filter=custom_filter, keep_relations=incorrect_bool
+        )
     except ValueError as e:
         if "'keep_relations' should be boolean type: True or False" in str(e):
             pass
         else:
             raise e
 
-
     try:
-        gdf = osm.get_data_by_custom_criteria(custom_filter=custom_filter,
-                                             keep_relations=False,
-                                             keep_ways=False,
-                                             keep_nodes=False
-                                             )
+        gdf = osm.get_data_by_custom_criteria(
+            custom_filter=custom_filter,
+            keep_relations=False,
+            keep_ways=False,
+            keep_nodes=False,
+        )
     except ValueError as e:
         if "At least on of the following parameters should be True" in str(e):
             pass
@@ -252,15 +278,16 @@ def test_using_incorrect_booleans(test_pbf):
 
 def test_using_incorrect_osm_keys(test_pbf):
     from pyrosm import OSM
+
     osm = OSM(filepath=test_pbf)
 
     osm_keys = 1
     custom_filter = {"building": ["retail"]}
     # Test that passing incorrect data works as should
     try:
-        gdf = osm.get_data_by_custom_criteria(custom_filter=custom_filter,
-                                             osm_keys_to_keep=osm_keys
-                                             )
+        gdf = osm.get_data_by_custom_criteria(
+            custom_filter=custom_filter, osm_keys_to_keep=osm_keys
+        )
     except ValueError as e:
         if "'osm_keys_to_keep' -parameter should be of type str or list." in str(e):
             pass
@@ -278,11 +305,12 @@ def test_reading_with_custom_filters_with_including(test_pbf):
     gdf_all = osm.get_buildings()
 
     # Find out all 'building' tags
-    cnts = gdf_all['building'].value_counts()
+    cnts = gdf_all["building"].value_counts()
     for filter_, cnt in cnts.items():
         # Use the custom filter
-        filtered = osm.get_data_by_custom_criteria(custom_filter={'building': [filter_]},
-                                                  filter_type="keep")
+        filtered = osm.get_data_by_custom_criteria(
+            custom_filter={"building": [filter_]}, filter_type="keep"
+        )
 
         assert isinstance(filtered, GeoDataFrame)
         assert isinstance(filtered.loc[0, "geometry"], Polygon)
@@ -290,7 +318,7 @@ def test_reading_with_custom_filters_with_including(test_pbf):
         # Now should only have buildings with given key
         assert len(filtered["building"].unique()) == 1
 
-        required_cols = ['building', 'id', 'timestamp', 'version', 'geometry']
+        required_cols = ["building", "id", "timestamp", "version", "geometry"]
 
         for col in required_cols:
             assert col in filtered.columns
@@ -306,12 +334,13 @@ def test_reading_with_custom_filters_with_excluding(test_pbf):
     gdf_all = osm.get_buildings()
 
     # Find out all 'building' tags
-    cnts = gdf_all['building'].value_counts()
+    cnts = gdf_all["building"].value_counts()
     n = len(gdf_all)
     for filter_, cnt in cnts.items():
         # Use the custom filter
-        filtered = osm.get_data_by_custom_criteria(custom_filter={'building': [filter_]},
-                                                   filter_type="exclude")
+        filtered = osm.get_data_by_custom_criteria(
+            custom_filter={"building": [filter_]}, filter_type="exclude"
+        )
 
         assert isinstance(filtered, GeoDataFrame)
         assert isinstance(filtered.loc[0, "geometry"], Polygon)
@@ -319,7 +348,7 @@ def test_reading_with_custom_filters_with_excluding(test_pbf):
         # Now should not have the filter_ in buildings
         assert filter_ not in filtered["building"].unique()
 
-        required_cols = ['building', 'id', 'timestamp', 'version', 'geometry']
+        required_cols = ["building", "id", "timestamp", "version", "geometry"]
 
         for col in required_cols:
             assert col in filtered.columns
@@ -334,44 +363,50 @@ def test_reading_with_custom_filters_selecting_specific_osm_element(helsinki_pbf
 
     # Test getting only relations
     # ---------------------------
-    filtered = osm.get_data_by_custom_criteria(custom_filter={'building': True},
-                                              filter_type="keep",
-                                              keep_nodes=False,
-                                              keep_ways=False,
-                                              keep_relations=True)
+    filtered = osm.get_data_by_custom_criteria(
+        custom_filter={"building": True},
+        filter_type="keep",
+        keep_nodes=False,
+        keep_ways=False,
+        keep_relations=True,
+    )
     assert isinstance(filtered, GeoDataFrame)
 
     # Now should only have 'relation' osm_type
-    assert len(filtered['osm_type'].unique()) == 1
-    assert filtered['osm_type'].unique()[0] == 'relation'
+    assert len(filtered["osm_type"].unique()) == 1
+    assert filtered["osm_type"].unique()[0] == "relation"
     assert len(filtered) == 66
 
     # Test getting only ways
     # ---------------------------
-    filtered = osm.get_data_by_custom_criteria(custom_filter={'building': True},
-                                              filter_type="keep",
-                                              keep_nodes=False,
-                                              keep_ways=True,
-                                              keep_relations=False)
+    filtered = osm.get_data_by_custom_criteria(
+        custom_filter={"building": True},
+        filter_type="keep",
+        keep_nodes=False,
+        keep_ways=True,
+        keep_relations=False,
+    )
     assert isinstance(filtered, GeoDataFrame)
 
     # Now should only have 'way' osm_type
-    assert len(filtered['osm_type'].unique()) == 1
-    assert filtered['osm_type'].unique()[0] == 'way'
+    assert len(filtered["osm_type"].unique()) == 1
+    assert filtered["osm_type"].unique()[0] == "way"
     assert len(filtered) == 422
 
     # Test getting only nodes
     # ---------------------------
-    filtered = osm.get_data_by_custom_criteria(custom_filter={'building': True},
-                                              filter_type="keep",
-                                              keep_nodes=True,
-                                              keep_ways=False,
-                                              keep_relations=False)
+    filtered = osm.get_data_by_custom_criteria(
+        custom_filter={"building": True},
+        filter_type="keep",
+        keep_nodes=True,
+        keep_ways=False,
+        keep_relations=False,
+    )
     assert isinstance(filtered, GeoDataFrame)
 
     # Now should only have 'node' osm_type
-    assert len(filtered['osm_type'].unique()) == 1
-    assert filtered['osm_type'].unique()[0] == 'node'
+    assert len(filtered["osm_type"].unique()) == 1
+    assert filtered["osm_type"].unique()[0] == "node"
     assert len(filtered) == 36
 
 
@@ -383,9 +418,10 @@ def test_custom_filters_with_custom_keys(helsinki_region_pbf):
     osm = OSM(filepath=helsinki_region_pbf)
 
     # Test reading public transport related data
-    filtered = osm.get_data_by_custom_criteria(custom_filter={'public_transport': True},
-                                              filter_type="keep",
-                                              )
+    filtered = osm.get_data_by_custom_criteria(
+        custom_filter={"public_transport": True},
+        filter_type="keep",
+    )
     assert isinstance(filtered, GeoDataFrame)
     assert len(filtered) == 5542
 
@@ -397,29 +433,27 @@ def test_custom_filters_with_custom_keys(helsinki_region_pbf):
     routes = ["bus", "ferry", "railway", "subway", "train", "tram", "trolleybus"]
     rails = ["tramway", "light_rail", "rail", "subway", "tram"]
     # 'express' comes with routes
-    bus = ['yes', "express"]
+    bus = ["yes", "express"]
 
-    transit = osm.get_data_by_custom_criteria(custom_filter={
-        'route': routes,
-        'railway': rails,
-        'bus': bus},
+    transit = osm.get_data_by_custom_criteria(
+        custom_filter={"route": routes, "railway": rails, "bus": bus},
         filter_type="keep",
-        keep_nodes=False)
+        keep_nodes=False,
+    )
 
     required_columns = ["railway", "bus", "route"]
     for col in required_columns:
         assert col in transit.columns
 
     # Check individual counts
-    correct_counts = {'railway': 1456,
-                      'route': 824,
-                      'bus': 79}
+    correct_counts = {"railway": 1456, "route": 824, "bus": 79}
 
     for col in required_columns:
         cnt = len(transit[col].dropna())
         correct = correct_counts[col]
-        assert cnt == correct, f"Incorrect count for {col}. " \
-                               f"Should have {correct}, found {cnt}."
+        assert cnt == correct, (
+            f"Incorrect count for {col}. " f"Should have {correct}, found {cnt}."
+        )
 
     # Ensure that the data contains only data specified in the filters
     unique_route = transit["route"].unique()
@@ -447,7 +481,6 @@ def test_custom_filters_with_custom_keys(helsinki_region_pbf):
 
         assert v in bus
 
-
     assert isinstance(transit, GeoDataFrame)
     assert len(transit) == 2357
 
@@ -486,10 +519,12 @@ def test_adding_extra_attribute(helsinki_pbf):
     osm = OSM(filepath=helsinki_pbf)
     gdf = osm.get_data_by_custom_criteria({"highway": True})
     extra_col = "wikidata"
-    extra = osm.get_data_by_custom_criteria({"highway": True}, extra_attributes=[extra_col])
+    extra = osm.get_data_by_custom_criteria(
+        {"highway": True}, extra_attributes=[extra_col]
+    )
 
     # The extra should have one additional column compared to the original one
-    assert extra.shape[1] == gdf.shape[1]+1
+    assert extra.shape[1] == gdf.shape[1] + 1
     # Should have same number of rows
     assert extra.shape[0] == gdf.shape[0]
     assert extra_col in extra.columns
@@ -523,8 +558,9 @@ def test_using_two_level_custom_filter(helsinki_region_pbf):
     osm = OSM(filepath=helsinki_region_pbf)
     osm_keys = ["building"]
     custom_filter = {"amenity": ["school"]}
-    gdf = osm.get_data_by_custom_criteria(custom_filter=custom_filter,
-                                          osm_keys_to_keep=osm_keys)
+    gdf = osm.get_data_by_custom_criteria(
+        custom_filter=custom_filter, osm_keys_to_keep=osm_keys
+    )
 
     assert gdf.shape == (72, 25)
 
@@ -535,13 +571,15 @@ def test_using_two_level_custom_filter(helsinki_region_pbf):
 
 def test_exclude_filtering_nodes_and_relations(helsinki_pbf):
     from pyrosm import OSM
+
     # Initialize the reader
     osm = OSM(helsinki_pbf)
     custom_filter = {"amenity": ["library"]}
 
-    gdf = osm.get_data_by_custom_criteria(custom_filter,
-                                          filter_type="exclude",
-                                          )
+    gdf = osm.get_data_by_custom_criteria(
+        custom_filter,
+        filter_type="exclude",
+    )
     assert gdf.shape == (1081, 37)
     assert "library" not in gdf["amenity"].unique().tolist()
 
@@ -549,13 +587,12 @@ def test_exclude_filtering_nodes_and_relations(helsinki_pbf):
     assert gdf["osm_type"].unique().tolist() == ["node", "way", "relation"]
 
     # Test other way around
-    gdf = osm.get_data_by_custom_criteria(custom_filter,
-                                          filter_type="keep",
-                                          )
+    gdf = osm.get_data_by_custom_criteria(
+        custom_filter,
+        filter_type="keep",
+    )
     assert gdf.shape == (7, 23)
     assert gdf["amenity"].unique().tolist() == ["library"]
 
     # There should be nodes and ways (no relations)
     assert gdf["osm_type"].unique().tolist() == ["node", "way"]
-
-
